{{ title }}

## Controls

Trait
Sample
Annotation
Top Gene ()

### Summary

Traits
Samples
Annotations

### Contents

Loading data...

If this message persists, please check that js_data/ folder exists with the required .js files.

##

Interactive 3D view of spatial data with -log10(p) values and annotations side by side.

Trait:
Annotation:

### -log10(p) -

Loading 3D Scene...
No 3D visualization available for this trait.

### Annotation -

Loading 3D Scene...
No 3D visualization available for this annotation.

## -

Spatial distribution of -log10(p) values and annotations side by side.

Trait:
Annotation:
Loading sample data...

### -log10(p) -

Loading trait data...

### Annotation -

## - -

Gene expression and GSS distribution for selected sample.

Gene:
Sample:
Loading gene data...

### Gene Diagnostic Table

Gene | PCC | Annotation | Median GSS
--- | --- | --- | ---

Showing of genes

## -

Spatial distribution of annotations across samples.

Select an annotation category to view the plot.

##

UMAP visualization of cell and niche embeddings with -log10(p) and annotations.

Trait:
Annotation:
spots

### Cell Embedding

#### -log10(p) -

#### Annotation -

### Niche Embedding

#### -log10(p) -

#### Annotation -

##

GWAS results. Red = top PCC genes. Green diamond = selected gene.

##

Statistical significance of annotations.

View:

Trait | Annotation | Sample | -log10P (Cauchy) | -log10P (Median) | 95% Quantile (-log10P) | Total Spots
--- | --- | --- | --- | --- | --- | ---

###

Metric:
Cluster
0-1 Normalize

##

Configuration and summary statistics.

Traits

Samples

Annotation Categories

### Configuration